import { IDisposable } from '@lumino/disposable';
import { BasicMouseHandler, DataGrid, DataModel, ResizeHandle } from 'tde-datagrid';
import { Signal } from '@lumino/signaling';
export declare class RichMouseHandler extends BasicMouseHandler {
    private _moveLine;
    constructor(options: RichMouseHandler.IOptions);
    get resizeSignal(): Signal<this, null>;
    get rightClickSignal(): Signal<this, DataGrid.HitTestResult>;
    cursorForHandle(region: ResizeHandle): string;
    cursorByRegion(): string;
    onMouseHover(grid: DataGrid, event: MouseEvent): void;
    /**
     * Handle the mouse down event for the data grid.
     *
     * @param grid - The data grid of interest.
     *
     * @param event - The mouse down event of interest.
     */
    onMouseDown(grid: DataGrid, event: MouseEvent): void;
    release(): void;
    handleGrabbing(): void;
    getShadowRegion(region: DataModel.CellRegion | 'void', row: number, column: number): Array<number>;
    /**
     * Handle the mouse move event for the data grid.
     *
     * @param grid - The data grid of interest.
     *
     * @param event - The mouse move event of interest.
     */
    onMouseMove(grid: DataGrid, event: MouseEvent): void;
    /**
     * Moves the line based on the position of the cursor and shadow
     * @param grid
     * @param event
     */
    updateLinePos(grid: DataGrid, event: MouseEvent): void;
    /**
     *
     * @param grid
     * @param event
     */
    onMouseUp(grid: DataGrid, event: MouseEvent): void;
    /**
     * Handle the context menu event for the data grid.
     *
     * @param grid - The data grid of interest.
     *
     * @param event - The context menu event of interest.
     */
    onContextMenu(grid: DataGrid, event: MouseEvent): void;
    private _grid;
    private _event;
    private _cursor;
    private _moveData;
    private _rightClickSignal;
    private _resizeSignal;
    private _selectionIndex;
}
export declare type MoveData = {
    /**
     * The descriminated type for the data.
     */
    readonly type: 'move';
    /**
     * The region which holds the section being moved.
     */
    readonly region: DataModel.CellRegion;
    readonly row: number;
    readonly column: number;
    readonly override: IDisposable;
    readonly localX: number;
    readonly localY: number;
    readonly timeout: number;
};
export declare namespace RichMouseHandler {
    interface IOptions {
        grid: DataGrid;
    }
}
export declare namespace RichMouseHandler {
    interface IOptions {
        grid: DataGrid;
    }
}
